<?php
require_once('Objects/BasicObject.php');
/**
 * The File object represents a file on the website.
 */
class File extends BasicObject {
	private $_category_icon;
	private $_url;
	private $_name;
	private $_extra_info;
	#protected $_html;

	public function __construct($data, $baseurl) {
		$this->_category_icon = $data['category_icon'];
		$this->_name = $data['name'];
		$this->_extra_info = $data['extra_info'];
		#$this->_html = $data['html'];

		/* If it's not an array, we didn't get any attributes. */
		if (!is_array($data['url'])) {
			$this->_url = $data['url'];
			/* If it doesn't start with 'http://' prefix it with the baseurl. */
			if (substr($this->_url, 0, 7) != 'http://') {
				$this->_url = $baseurl . $this->_url;
			}
		/* We got attributes, check them. */
		} else {
			$attributes = $data['url']['attributes'];
			$url = $data['url'][0];
			$this->_url = $url;
			/**
			 * Get the filesize/last modified information and put it in
			 * $this->_extra_info.
			 */
			if ($attributes['local_file'] == 'true') {
				if (is_file($url) && is_readable($url)) {
					$size = round((@filesize($url) / 1024));
					$ext = substr($url, (strrpos($url, '.')+1));
					$date = date('F j, Y, g:i a', @filemtime($url));
					$info = "{$size}K {$ext} file, last update: {$date}";
					$this->_extrainfo = $info;
				}
			}
		}

		/**
		 * If the extra_info doesn't have a starting paranthesis, add
		 * paranthesises around the extra information.
		 */
		if (!empty($this->_extra_info)
			&& substr($this->_extra_info, 0, 1) != '(') {
			$this->_extra_info = '(' . $this->_extra_info . ')';
		}
	}

	/* Get the category icon. */
	public function getCategoryIcon() {
		return $this->_category_icon;
	}

	/* Get the URL. */
	public function getURL() {
		return $this->_url;
	}

	/* Get the name. */
	public function getName() {
		return $this->_name;
	}

	/* Get the extra information. */
	public function getExtraInfo() {
		return $this->_extra_info;
	}
}
?>
